%% Materialovy bod

% parametry modelu
E0=21.04;			% [GPa]
E=[9902 3841 1911 747 404 105];	% [GPa]
tau=[0.001 0.01 0.1 1 10 100];	% [den]
M=length(E);		% pocet clanku

% zatezovaci funkce
sgm=5;			% [MPa]
om=pi/100; 
function y=f(t,sgm,om)	
	y=sgm*sin(om*t);		
end	

% vektor casu pro vyhodnoceni f(t):
t=linspace(0,100,9)' ;	% [den]
t(1)=0.1; 

% presne analyticke reseni: deformace v case t [1e-6]
for i=1:length(t)
as(i)=sgm*(1/E0*sin(om*t(i))  ...
	+sum(1./(E.*(1.+tau.^2*om^2))  ...
	.*(sin(om*t(i))-om*tau.*(cos(om*t(i))-exp(-t(i)./tau)))))*1000;
end

% exponencialni algoritmus
n= 10000;			% pocet kroku
dt=100/n;
u=1;
theta=exp(-dt./tau);
psi=tau.*(1-theta)./dt;
eps_p=zeros(1,M);
eps_n=zeros(1,M);
deps_p=zeros(1,M);
deps_n=zeros(1,M);
for i=1:n
	del_sgm=f(i*dt,sgm,om)-f((i-1)*dt,sgm,om); 
	deps_n=theta.*deps_p.+(1-theta)./(dt*E)*del_sgm;
	eps_n=eps_p.+dt*psi.*deps_p.+(1-psi)*del_sgm./E;
	deps_p=deps_n;
	eps_p=eps_n;
	if i*dt==t(u), ea(u)=(f(i*dt,sgm,om)/E0+sum(eps_n))*1000; 
		u=u+1; 
	end	
end

% inverzni Laplaceova transformace
function[Y]=F_p(p,sgm,om,E0,E,tau,M)
F=sgm*om./(p.^2+om^2);	% Laplaceuv obraz zatezovaci funkce
J=1./(p*E0)+ ...
	1./p.*(1./(E.*tau)*(1./(p*ones(1,M)+1./(ones(length(p),1)*tau)))')';
Y=p.*J.*F; 
end
pol=0; 
tol=1e-12; 	
Lt=invlap('F_p',t,pol,tol,sgm,om,E0,E,tau,M)*1000;

%format long
format bank
% vysledne hodnoty a relativni chyby obou algoritmu
[t f(t,sgm,om) as' (Lt-as')./as'*1e9 (ea'-as')./as'*1e9]







