%% Materialovy bod (pri lichobeznikovem zatizeni)

% Heavisideova funkce
function H=H(t,t0) 
	if t<t0, H=0;
		else H=1; 
	end
end

% parametry modelu
E0= 21.04;			% [GPa]
E = [1911 747 404 105];	% [GPa]
tau = [0.1 1 10 100];		% [den]
M=length(E); 			% pocet clanku

% zatezovaci funkce (t oblast)
sgm=5;			% [MPa]
t1=10; 
t2=60; 
t3=70;
function y=f(t,sgm,t1,t2,t3)		
y=sgm*(t/t1-(t-t1)/t1*H(t,t1)-(t-t2)/(t3-t2)*H(t,t2)+(t-t3)/(t3-t2)*H(t,t3));	
end	

% vektor casu pro vyhodnoceni f(t)
t=(0:1:100)';	% [den]
t(1)=0.1; 

% zatizeni
for i=1:length(t)
load(i)=f(t(i),sgm,t1,t2,t3);
end

% presne analyticke reseni: deformace v case t [1e-6]
for i=1:length(t)
as(i) = sgm* ...
 ((1/(E0*t1)*t(i)+sum(1./(E*t1) ...
		.*(t(i)-tau+tau.*exp(-t(i)./tau))))  ...
- (1/(E0*t1)*(t(i)-t1)+sum(1./(E*t1) ...
		.*(t(i)-t1-tau+tau.*exp(-(t(i)-t1)./tau))))*H(t(i),t1) ...
- (1/(E0*(t3-t2))*(t(i)-t2)+sum(1./(E*(t3-t2)) ...
		.*(t(i)-t2-tau+tau.*exp(-(t(i)-t2)./tau))))*H(t(i),t2) ...
+ (1/(E0*(t3-t2))*(t(i)-t3)+sum(1./(E*(t3-t2)) ...
		.*(t(i)-t3-tau+tau.*exp(-(t(i)-t3)./tau))))*H(t(i),t3))*1000;
end

%exponencialni algoritmus
n= 10000;			% pocet kroku
dt=100/n;
u=1;
theta=exp(-dt./tau);
psi=tau.*(1-theta)./dt;
eps_p=zeros(1,M);
eps_n=zeros(1,M);
deps_p=zeros(1,M);
deps_n=zeros(1,M);
for i=1:n
	del_sgm=f(i*dt,sgm,t1,t2,t3)-f((i-1)*dt,sgm,t1,t2,t3); 
	deps_n=theta.*deps_p.+(1-theta)./(dt*E)*del_sgm;
	eps_n=eps_p.+dt*psi.*deps_p.+(1-psi)*del_sgm./E;
	deps_p=deps_n;
	eps_p=eps_n;
	if i*dt==t(u), ea(u)=(f(i*dt,sgm,t1,t2,t3)/E0+sum(eps_n))*1000; 
		u=u+1; 
	end	
end

% inverzni Laplaceova transformace
function[Y]=F_p(p,sgm,t1,t2,t3,E0,E,tau,M)
F=sgm/t1.*1./p.^2-sgm/t1.*1./p.^2.*exp(-t1.*p) ...  % Laplaceuv obraz zatezovaci funkce
-sgm/(t3-t2).*1./p.^2.*exp(-t2.*p)+sgm/(t3-t2).*1./p.^2.*exp(-t3.*p);	
J=1./(p*E0)+ ...
	1./p.*(1./(E.*tau)*(1./(p*ones(1,M)+1./(ones(length(p),1)*tau)))')';
Y=p.*J.*F; 
end
pol=0; 		
tol=1e-12; 		
Lt=invlap('F_p',t,pol,tol,sgm,t1,t2,t3,E0,E,tau,M)*1000;

%format long
format bank
% absolutni chyba obou algoritmu oproti analytickemu reseni
[t load' as' Lt-as' ea'-as']










