%% Vlaknovy kompozit pri jednoose napjatosti

% parametry modelu
fm=0.8;						% podil matrice (viskoelasticka)
fi=1-fm;						% podil inkluze (elasticka)
Ei0=386;						% [GPa] 
Em0=21.04;					% [GPa]
E=[9902 3841 1911 747 404 105];		% [GPa]
tau=[0.001 0.01 0.1 1 10 100];		% [den]
M=length(E);					% pocet clanku (matrice) 

% zatezovaci funkce
sgm=20;			% [MPa]
om=pi/100; 
function y=f(t,sgm,om)	
	y=sgm*sin(om*t);		
end	

% vektor casu pro vyhodnoceni f(t)
t=linspace(0,100,9)' ;	% [den]
t(1)=0.1; 

% exponencialni algoritmus
n=10000;			% pocet kroku
dt=100/n;
u=1;
theta=exp(-dt./tau);
psi=tau.*(1-theta)./dt;
Em=(1/Em0+sum(1./E.*(1.-psi))).^-1;	% algoritnicka tuhost matrice
Eeff=fm*Em+fi*Ei0;					% algoritnicka efektivni tuhost 
eps=0;
del_eps=0;
eps_p=zeros(1,M);
eps_n=zeros(1,M);
deps_p=zeros(1,M);
deps_n=zeros(1,M);
for i=1:n
	del_sgm=f(i*dt,sgm,om)-f((i-1)*dt,sgm,om); 
	del_eps=fm*Em/Eeff*dt*psi*deps_p'+del_sgm/Eeff;
	del_sgm_i=Ei0*del_eps;
	if fm>0 del_sgm_m=(del_sgm-fi*del_sgm_i)/fm; 
		else dsgm_m=0; 
	end;
	deps_n=theta.*deps_p.+(1-theta)./(dt*E)*del_sgm_m;
	eps_n=eps_p.+dt*psi.*deps_p.+(1-psi)*del_sgm_m./E;
	deps_p=deps_n;
	eps_p=eps_n;
	eps=eps+del_eps;
	if i*dt==t(u), ea(u)=eps*1000; 
		u=u+1;
	end
end

% inverzni Laplaceova transformace
function[Y]=F_p(p,sgm,om,fm,fi,Ei0,Em0,E,tau,M)
F=sgm*om./(p.^2+om^2);	% Laplaceuv obraz zatezovaci funkce
Jm=1./(p*Em0) ...
	+1./p.*(1./(E.*tau)*(1./(p*ones(1,M)+1./(ones(length(p),1)*tau)))')';
Ji=1./(p*Ei0);
Jeff=(fm./Jm+fi./Ji).^-1;
Y=p.*Jeff.*F; 
end
pol=0; 		
tol=1e-12; 		
Lt=invlap('F_p',t,pol,tol,sgm,om,fm,fi,Ei0,Em0,E,tau,M)*1000;

%format long
format bank
% vysledne hodnoty a relativni chyba exponencialniho algoritmu
[t f(t,sgm,om) Lt  (ea'-Lt)./Lt*1e9]






